@@ -7,7 +7,7 @@ import shelve
 import os
 import requests
 import logging
-from .user import User
+from .types import User, HerreConfig
 
 logger = logging.getLogger(__name__)
 
@@ -17,19 +17,31 @@ class AuthError(Exception):
     pass
 
 
+
+
+
 class BaseAuthBackend(ABC):
 
 
-    def __init__(self, host, port, protocol="http", token_url="o/token", check_endpoint="auth/", scopes=None, **kwargs) -> None:
+    def __init__(self, config: HerreConfig, token_url="o/token/", authorize_url="o/authorize/", check_endpoint="auth/") -> None:
+        # Needs to be set for oauthlib
+        os.environ["OAUTHLIB_INSECURE_TRANSPORT"] = "0" if config.secure else "1"
 
-        self.base_url = f"{protocol}://{host}:{port}/"
+
+
+        self.base_url = f'{"https" if config.secure else "http"}://{config.host}:{config.port}/'
         self.check_url = self.base_url + check_endpoint
-        self.scopes = scopes + ["introspection"] if scopes else ["introspection"]
-        print(self.scopes)
+        self.auth_url = self.base_url + authorize_url
+        self.token_url = self.base_url + token_url
+        self.scopes = config.scopes + ["introspection"]
+        self.client_id = config.client_id
+        self.client_secret = config.client_secret  
+
         self.scope = " ".join(self.scopes)
         self._user = None
 
-        config_name = "access.cfg"
+        # Lets check if we already have a local toke
+        config_name = "token.db"
         run_path = os.path.abspath(os.getcwd())
         self.config_path = os.path.join(run_path, config_name)
 
@@ -49,6 +61,8 @@ class BaseAuthBackend(ABC):
     def fetchToken(self, loop=None) -> str:
         raise NotImplementedError("This is an abstract Class")
 
+    def refetchToken(self) -> str:
+        raise NotImplementedError("This is an abstract Class")
 
     def getUser(self):
         assert self.token is not None, "Need to authenticate before accessing the User"
@@ -84,13 +98,3 @@ class BaseAuthBackend(ABC):
                     return self.token
                 
             return self.token
-
-
-
-    @abstractmethod
-    def getClientType(self) -> ClientType:
-        raise NotImplementedError("This is an Abstract Class")
-
-    @abstractmethod
-    def getProtocol(self):
-        raise NotImplementedError("This is an Abstract Class")
\ No newline at end of file
