@@ -1,6 +1,8 @@
+import logging
 import re
 from typing import Generator, Generic, List, Type, TypeVar
 
+logger = logging.getLogger(__name__)
 
 
 gqlparsed_with_variables = re.compile(r"[\s]*(?P<type>subscription|query|mutation)\s*(?P<operation>[a-zA-Z]*)\((?P<arguments>[^\)]*)\)[\s]*{[\s]*(?P<firstchild>[^\(:]*).*")
@@ -88,7 +90,11 @@ class TypedGQL(GQL, Generic[MyType]):
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
         assert returnedobject is not None, "We received nothing back from the Server! Refine your Query!"
         if isinstance(returnedobject,list): return ListQuery([self.cls(**item) for item in returnedobject])
-        return self.cls(**returnedobject)
+        try:
+            return self.cls(**returnedobject)
+        except Exception as e:
+            logger.error(returnedobject)
+            raise e
 
     def run(self, ward=None, variables=None, **kwargs) -> MyType:
         from bergen.registries.arnheim import get_current_arnheim
@@ -126,6 +132,8 @@ class Query(GQL, Generic[MyType]):
         ward = ward or self._cls.get_ward()
         returnedobject = ward.run(self, variables=variables,**kwargs)
         if isinstance(returnedobject,list): raise Exception("Received a freaking list..., Please run QueryList")
+        if not isinstance(returnedobject, dict):
+            return self.cls(returnedobject) if returnedobject else None
         return self.cls(**returnedobject) if returnedobject else None
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
@@ -184,7 +192,9 @@ class AsyncQuery(GQL, Generic[MyType]):
         ward = ward or self._cls.get_ward()
         returnedobject = await ward.run_async(self, variables=variables,**kwargs)
         if isinstance(returnedobject,list): raise Exception("Received a freaking list..., Please run QueryList")
-        return self.cls(**returnedobject) if returnedobject else None
+        if not isinstance(returnedobject, dict):
+            return self.cls(returnedobject) if returnedobject else None
+        return self.cls(**returnedobject) 
 
     def subscribe(self, ward=None, **kwargs) -> Generator[MyType, None,None]:
         from bergen.registries.arnheim import get_current_arnheim
