@@ -18,7 +18,7 @@ import requests
 class AIOHttpGraphQLWard(BaseGraphQLWard):
     can_subscribe = False
 
-    def __init__(self, port, host, protocol, token, loop) -> None:
+    def __init__(self, port, host, protocol, token, loop=None) -> None:
         super().__init__(port=port, host=host, protocol=protocol, token=token, loop=loop)
 
     async def configure(self):
@@ -32,4 +32,7 @@ class AIOHttpGraphQLWard(BaseGraphQLWard):
         response = await self.transport.execute(query_node, variable_values=variables)
         if response.errors:
             raise GraphQLException(str(response.errors))
-        return the_query.extract(response.data)
\ No newline at end of file
+        return the_query.extract(response.data)
+
+    async def disconnect(self):
+        await self.transport.close()
\ No newline at end of file
